/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.plugin.use.resolve.internal;

import org.gradle.api.internal.plugins.PluginImplementation;
import org.gradle.plugin.use.PluginId;

public interface PluginResolveContext {
    void addLegacy(PluginId pluginId, String m2RepoUrl, Object dependencyNotation);

    void addLegacy(PluginId pluginId, Object dependencyNotation);

    void add(PluginImplementation<?> plugin);

    void addFromDifferentLoader(PluginImplementation<?> plugin);
}
